# 0.9.0
- Disable fractions replacement 

# 0.8.1
- Add non-breaking space after numbers up to 4 digits. (Before it was up to 3 digits)

# 0.8.0
- Prohibits line breaks if two numbers are separated by m-dash symbol.
- The rules for the m-dash (—) `\u2014` are also applied to the horizontal bar (―) `\u2015`.

# 0.2.0
- Add expression to replace positional spaces with non-breakable spaces
after certain words
